@@ -79,11 +79,11 @@ buffer_changed (GtkTextBuffer *buffer, gpointer data)
 	   the timer triggers, we will save the buffer if there have
 	   been no subsequent changes.  */
 	++stickynotes->last_timeout_data;
-	g_timeout_add (1000 * 10, (GSourceFunc) timeout_happened,
+	g_timeout_add_seconds (10, (GSourceFunc) timeout_happened,
 		       GUINT_TO_POINTER (stickynotes->last_timeout_data));
 }
 
-/* Create a new (empty) Sticky Note at a specific position 
+/* Create a new (empty) Sticky Note at a specific position
    and with specific size */
 StickyNote *
 stickynote_new_aux (GdkScreen *screen, gint x, gint y, gint w, gint h)
@@ -115,7 +115,7 @@ stickynote_new_aux (GdkScreen *screen, gint x, gint y, gint w, gint h)
 	gtk_widget_add_events (note->w_resize_se, GDK_BUTTON_PRESS_MASK);
 	note->w_resize_sw = GTK_WIDGET (gtk_builder_get_object (builder, "resize_sw_box"));
 	gtk_widget_add_events (note->w_resize_sw, GDK_BUTTON_PRESS_MASK);
-	
+
 	note->img_lock = GTK_IMAGE (gtk_builder_get_object (builder,
 	                "lock_img"));
 	note->img_close = GTK_IMAGE (gtk_builder_get_object (builder,
@@ -128,11 +128,11 @@ stickynote_new_aux (GdkScreen *screen, gint x, gint y, gint w, gint h)
 	/* deal with RTL environments */
 	gtk_widget_set_direction (GTK_WIDGET (gtk_builder_get_object (builder, "resize_bar")),
 			GTK_TEXT_DIR_LTR);
-	
+
 	note->w_menu = GTK_WIDGET (gtk_builder_get_object (builder, "stickynote_menu"));
 	note->ta_lock_toggle_item = GTK_TOGGLE_ACTION (gtk_builder_get_object (builder,
 	        "popup_toggle_lock"));
-	
+
 	note->w_properties = GTK_WIDGET (gtk_builder_get_object (builder,
 			"stickynote_properties"));
 	gtk_window_set_screen (GTK_WINDOW (note->w_properties), screen);
@@ -203,7 +203,7 @@ stickynote_new_aux (GdkScreen *screen, gint x, gint y, gint w, gint h)
 	gtk_widget_realize (note->w_window);
 
 	/* Connect a popup menu to all buttons and title */
-	/* GtkBuilder holds and drops the references to all the widgets it 
+	/* GtkBuilder holds and drops the references to all the widgets it
 	 * creates for as long as it exist (GtkBuilder). Hence in our callback
 	 * we would have an invalid GtkMenu. We need to ref it.
 	 */
@@ -249,7 +249,7 @@ stickynote_new_aux (GdkScreen *screen, gint x, gint y, gint w, gint h)
 			G_CALLBACK (stickynote_configure_cb), note);
 	g_signal_connect (G_OBJECT (note->w_window), "delete-event",
 			G_CALLBACK (stickynote_delete_cb), note);
-	
+
 	g_signal_connect (gtk_builder_get_object (builder,
 					"popup_create"), "activate",
 			G_CALLBACK (popup_create_cb), note);
@@ -305,7 +305,7 @@ void stickynote_free(StickyNote *note)
 
 	g_free(note->color);
 	g_free(note->font);
-	
+
 	g_free(note);
 }
 
@@ -375,7 +375,7 @@ response_cb (GtkWidget *dialog, gint id, gpointer data)
 				"ghelp:stickynotes_applet?stickynotes-settings-individual",
 				gtk_get_current_event_time (),
 				NULL);
-        else
+        else if (id == GTK_RESPONSE_CLOSE)
                 gtk_widget_hide (dialog);
 }
 
@@ -425,7 +425,7 @@ stickynote_set_color (StickyNote  *note,
 			g_free (note->color);
 		if (note->font_color)
 			g_free (note->font_color);
-		
+
 		note->color = color_str ?
 			g_strdup (color_str) : NULL;
 		note->font_color = font_color_str ?
@@ -440,7 +440,7 @@ stickynote_set_color (StickyNote  *note,
 		gtk_widget_set_sensitive (note->w_font_color,
 				note->color != NULL);
 	}
-	
+
 	/* If "force_default" is enabled or color_str is NULL,
 	 * then we use the default color instead of color_str. */
 	if (!color_str || gconf_client_get_bool (stickynotes->gconf,
@@ -484,11 +484,11 @@ stickynote_set_color (StickyNote  *note,
 		/* Make 4 shades of the color, getting darker from the
 		 * original, plus black and white */
 		gint i;
-		
+
 		for (i = 0; i <= 3; i++)
 		{
 			gdk_color_parse (color_str_actual, &colors[i]);
-			
+
 			colors[i].red = (colors[i].red * (10 - i)) / 10;
 			colors[i].green = (colors[i].green * (10 - i)) / 10;
 			colors[i].blue = (colors[i].blue * (10 - i)) / 10;
@@ -518,7 +518,7 @@ stickynote_set_color (StickyNote  *note,
 		rc_style->color_flags[GTK_STATE_NORMAL] = 0;
 		rc_style->color_flags[GTK_STATE_ACTIVE] = 0;
 	}
-	
+
 	g_object_ref (G_OBJECT (rc_style));
 
 	/* Apply the style to the widgets */
@@ -530,15 +530,15 @@ stickynote_set_color (StickyNote  *note,
 	gtk_widget_modify_style (note->w_close, rc_style);
 	gtk_widget_modify_style (note->w_resize_se, rc_style);
 	gtk_widget_modify_style (note->w_resize_sw, rc_style);
-	
+
 	g_object_unref (G_OBJECT (rc_style));
-	
+
 	if (font_color_str_actual)
 	{
 		GdkColor font_color;
 
 		gdk_color_parse (font_color_str_actual, &font_color);
-		
+
 		gtk_widget_modify_text (note->w_window,
 				GTK_STATE_NORMAL, &font_color);
 		gtk_widget_modify_text (note->w_window,
@@ -580,7 +580,7 @@ stickynote_set_font (StickyNote *note, const gchar *font_str, gboolean save)
 		gtk_widget_set_sensitive (note->w_font_label, note->font != NULL);
 		gtk_widget_set_sensitive(note->w_font, note->font != NULL);
 	}
-	
+
 	/* If "force_default" is enabled or font_str is NULL,
 	 * then we use the default font instead of font_str. */
 	if (!font_str || gconf_client_get_bool (stickynotes->gconf,
@@ -646,7 +646,7 @@ stickynote_set_visible (StickyNote *note, gboolean visible)
 	if (visible)
 	{
 		gtk_window_present (GTK_WINDOW (note->w_window));
-		
+
 		if (note->x != -1 || note->y != -1)
 			gtk_window_move (GTK_WINDOW (note->w_window),
 					note->x, note->y);
@@ -695,7 +695,7 @@ stickynote_set_visible (StickyNote *note, gboolean visible)
 void stickynotes_add (GdkScreen *screen)
 {
 	StickyNote *note;
-		
+
 	note = stickynote_new (screen);
 
 	stickynotes->notes = g_list_append(stickynotes->notes, note);
@@ -724,7 +724,7 @@ void stickynotes_remove(StickyNote *note)
 
 		/* Remove the note from the linked-list of all notes */
 		stickynotes->notes = g_list_remove(stickynotes->notes, note);
-		
+
 		/* Update tooltips */
 		stickynotes_applet_update_tooltips();
 
@@ -745,9 +745,9 @@ stickynotes_save_now (void)
 	GtkTextBuffer *buffer;
 	GtkTextIter start, end;
 	gchar *body;
-	
+
 	gint i;
-	
+
 	/* Create a new XML document */
 	xmlDocPtr doc = xmlNewDoc(XML_CHAR ("1.0"));
 	xmlNodePtr root = xmlNewDocNode(doc, NULL, XML_CHAR ("stickynotes"), NULL);
@@ -757,7 +757,7 @@ stickynotes_save_now (void)
 
 	wnck_screen = wnck_screen_get_default ();
 	wnck_screen_force_update (wnck_screen);
-	
+
 	/* For all sticky notes */
 	for (i = 0; i < g_list_length(stickynotes->notes); i++) {
 		WnckWindow *wnck_win;
@@ -769,7 +769,7 @@ stickynotes_save_now (void)
 		/* Retrieve the window size of the note */
 		gchar *w_str = g_strdup_printf("%d", note->w);
 		gchar *h_str = g_strdup_printf("%d", note->h);
-		
+
 		/* Retrieve the window position of the note */
 		gchar *x_str = g_strdup_printf("%d", note->x);
 		gchar *y_str = g_strdup_printf("%d", note->y);
@@ -785,20 +785,20 @@ stickynotes_save_now (void)
 				wnck_window_get_workspace (wnck_win));
 		else
 			note->workspace = 0;
-		
+
 		/* Retrieve the title of the note */
 		title = gtk_label_get_text(GTK_LABEL(note->w_title));
 
 		/* Retrieve body contents of the note */
 		buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(note->w_body));
-		
+
 		gtk_text_buffer_get_bounds(buffer, &start, &end);
 		body = gtk_text_iter_get_text(&start, &end);
 
 		/* Save the note as a node in the XML document */
 		{
 			xmlNodePtr node = xmlNewTextChild(root, NULL, XML_CHAR ("note"),
-					XML_CHAR (body));		
+					XML_CHAR (body));
 			xmlNewProp(node, XML_CHAR ("title"), XML_CHAR (title));
 			if (note->color)
 				xmlNewProp (node, XML_CHAR ("color"), XML_CHAR (note->color));
@@ -816,7 +816,7 @@ stickynotes_save_now (void)
 			if (note->workspace > 0)
 			{
 				char *workspace_str;
-				
+
 				workspace_str = g_strdup_printf ("%i",
 						note->workspace);
 				xmlNewProp (node, XML_CHAR ("workspace"), XML_CHAR (workspace_str));
@@ -826,7 +826,7 @@ stickynotes_save_now (void)
 
 		/* Now that it has been saved, reset the modified flag */
 		gtk_text_buffer_set_modified(buffer, FALSE);
-	
+
 		g_free(x_str);
 		g_free(y_str);
 		g_free(w_str);
@@ -841,7 +841,7 @@ stickynotes_save_now (void)
 		xmlSaveFormatFile(file, doc, 1);
 		g_free(file);
 	}
-	
+
 	xmlFreeDoc(doc);
 
 	save_scheduled = FALSE;
@@ -852,7 +852,7 @@ stickynotes_save (void)
 {
   /* If a save isn't already schedules, save everything a minute from now. */
   if (!save_scheduled) {
-    g_timeout_add (60*1000, (GSourceFunc) stickynotes_save_now, NULL);
+    g_timeout_add_seconds (60, (GSourceFunc) stickynotes_save_now, NULL);
     save_scheduled = TRUE;
   }
 }
@@ -882,7 +882,7 @@ stickynotes_load (GdkScreen *screen)
 		stickynotes_save();
 		return;
 	}
-	
+
 	/* If the XML file is corrupted/incorrect, create a blank one */
 	root = xmlDocGetRootElement(doc);
 	if (!root || xmlStrcmp(root->name, XML_CHAR ("stickynotes")))
@@ -891,9 +891,9 @@ stickynotes_load (GdkScreen *screen)
 		stickynotes_save();
 		return;
 	}
-	
+
 	node = root->xmlChildrenNode;
-	
+
 	/* For all children of the root node (ie all sticky notes) */
 	new_notes = NULL;
 	new_nodes = NULL;
@@ -920,7 +920,7 @@ stickynotes_load (GdkScreen *screen)
 				g_free (w_str);
 				g_free (h_str);
 			}
-			
+
 			/* Retrieve and set the window position of the note */
 			{
 				gchar *x_str = (gchar *)xmlGetProp (node, XML_CHAR ("x"));
@@ -960,10 +960,10 @@ stickynotes_load (GdkScreen *screen)
 			{
 				gchar *color_str;
 				gchar *font_color_str;
-				
+
 				color_str = (gchar *)xmlGetProp (node, XML_CHAR ("color"));
 				font_color_str = (gchar *)xmlGetProp (node, XML_CHAR ("font_color"));
-				
+
 				if (color_str || font_color_str)
 					stickynote_set_color (note,
 							color_str,
@@ -1002,7 +1002,7 @@ stickynotes_load (GdkScreen *screen)
 				if (body) {
 					GtkTextBuffer *buffer;
 					GtkTextIter start, end;
-					
+
 					buffer = gtk_text_view_get_buffer(
 						GTK_TEXT_VIEW(note->w_body));
 					gtk_text_buffer_get_bounds(
@@ -1023,7 +1023,7 @@ stickynotes_load (GdkScreen *screen)
 				g_free(locked);
 			}
 		}
-		
+
 		node = node->next;
 	}
 
