@@ -47,7 +47,7 @@ typedef struct
 	GtkWidget *w_resize_se;		/* Sticky Note resize button (south east) */
 	GtkWidget *w_resize_sw;		/* Sticky Note resize button (south west) */
 
-	GtkWidget *w_lock_toggle_item;	/* Lock item in the popup menu */
+	GtkToggleAction *ta_lock_toggle_item; /* Lock item in the popup menu */
 
 	GtkImage *img_lock;		/* Lock image */
 	GtkImage *img_close;		/* Close image */
@@ -87,6 +87,7 @@ void stickynote_change_properties(StickyNote *note);
 void stickynotes_add(GdkScreen *screen);
 void stickynotes_remove(StickyNote *note);
 void stickynotes_save(void);
+void stickynotes_save_now (void);
 void stickynotes_load(GdkScreen *screen);
 
 #endif /* __STICKYNOTES_H__ */
